@@ -152,17 +152,28 @@ fn draw_item<B: Backend>(frame: &mut Frame<B>, app: &mut App, mut area: Rect) {
     let height = area.height;
     let num_to_render = (((height - 3) / item_widget_height) as usize).min(num_of_item);
 
-    let mut scroll_offset = if let Some(direction) = app.summary_scroll_state.queued_scroll.take() {
+    let scroll_offset = if let Some(direction) = app.summary_scroll_state.queued_scroll.take() {
         let new_offset = match direction {
             ScrollDirection::Up => {
-                if app.summary_scroll_state.offset == 0 {
-                    0
+                if app.summary_scroll_state.offset > 0 {
+                    let scrolloff = (app.summary_scroll_state.offset - 1).min(num_of_item);
+                    if app.current_item - 1 <= app.items[scrolloff].slot {
+                        scrolloff
+                    } else {
+                        app.summary_scroll_state.offset
+                    }
                 } else {
-                    (app.summary_scroll_state.offset - 1).min(num_of_item)
+                    0
                 }
             }
             ScrollDirection::Down => {
-                (app.summary_scroll_state.offset + 1).min(num_of_item - num_to_render)
+                let scrolloff =
+                    (app.summary_scroll_state.offset + 1).min(num_of_item - num_to_render);
+                if app.current_item + 1 >= app.items[scrolloff + num_to_render - 1].slot {
+                    scrolloff
+                } else {
+                    app.summary_scroll_state.offset
+                }
             }
         };
 
@@ -173,11 +184,6 @@ fn draw_item<B: Backend>(frame: &mut Frame<B>, app: &mut App, mut area: Rect) {
         app.summary_scroll_state.offset
     };
 
-    if num_to_render + scroll_offset > num_of_item {
-        scroll_offset -= (num_to_render + scroll_offset) - num_of_item;
-        app.summary_scroll_state.offset = scroll_offset;
-    }
-
     let mut layout = Layout::default()
         .constraints(
             [
@@ -189,8 +195,15 @@ fn draw_item<B: Backend>(frame: &mut Frame<B>, app: &mut App, mut area: Rect) {
         )
         .split(area);
 
-    let constraints = app
-        .items
+    let mut starting_index = scroll_offset;
+
+    if app.current_workspace != 0 {
+        for workspace in app.workspaces[0..app.current_workspace].iter() {
+            starting_index += workspace.num_of_item;
+        }
+    }
+
+    let constraints = app.items[starting_index..starting_index + num_to_render]
         .iter()
         .map(|i| {
             if i.workspace == app.workspaces[app.current_workspace].title {
@@ -203,7 +216,10 @@ fn draw_item<B: Backend>(frame: &mut Frame<B>, app: &mut App, mut area: Rect) {
 
     let item_layout = Layout::default().constraints(constraints).split(layout[1]);
 
-    for (idx, item) in app.items.iter_mut().enumerate() {
+    for (idx, item) in app.items[starting_index..starting_index + num_to_render]
+        .iter_mut()
+        .enumerate()
+    {
         if item.workspace == app.workspaces[app.current_workspace].title {
             frame.render_stateful_widget(ItemWidget {}, item_layout[idx], item);
         }
@@ -226,7 +242,20 @@ fn draw_item<B: Backend>(frame: &mut Frame<B>, app: &mut App, mut area: Rect) {
 
     let bottom_layout = Layout::default()
         .direction(Direction::Horizontal)
-        .constraints([Constraint::Min(0), Constraint::Length(3)].as_ref())
+        .constraints(
+            [
+                Constraint::Min(0),
+                Constraint::Length(
+                    app.workspaces[app.current_workspace]
+                        .num_of_item
+                        .to_string()
+                        .len() as u16
+                        * 2
+                        + 1,
+                ),
+            ]
+            .as_ref(),
+        )
         .split(layout[2]);
 
     frame.render_widget(
