@@ -92,6 +92,9 @@ fn handle_keys_add_workspace(keycode: KeyCode, modifiers: KeyModifiers, mut app:
                 app.mode = app.previous_mode;
             }
         }
+        (KeyModifiers::SHIFT, KeyCode::Char(c)) => {
+            app.add_workspace.add_char(c);
+        }
         (KeyModifiers::NONE, KeyCode::Char(c)) => {
             app.add_workspace.add_char(c);
         }
@@ -133,6 +136,9 @@ fn handle_keys_edit_workspace(keycode: KeyCode, modifiers: KeyModifiers, mut app
             app.edit_workspace.reset();
             app.mode = app.previous_mode;
         }
+        (KeyModifiers::SHIFT, KeyCode::Char(c)) => {
+            app.edit_workspace.add_char(c);
+        }
         (KeyModifiers::NONE, KeyCode::Char(c)) => {
             app.edit_workspace.add_char(c);
         }
@@ -188,10 +194,10 @@ fn handle_keys_display_workspace(
             app.mode = app::Mode::EditWorkspace;
         }
         KeyCode::Char('d') => {
-            let target = app.workspaces[app.current_workspace].title.clone();
-            app.items.retain(|i| i.workspace != target);
-
             if !app.workspaces.is_empty() {
+                let delete_workspace = app.workspaces[app.current_workspace].title.clone();
+                app.items.retain(|i| i.workspace != delete_workspace);
+
                 app.workspaces.remove(app.current_workspace);
             }
 
@@ -242,6 +248,9 @@ fn handle_keys_add_item(keycode: KeyCode, modifiers: KeyModifiers, mut app: &mut
                 app.add_item.has_expire_datetime = true;
             }
         }
+        (KeyModifiers::SHIFT, KeyCode::Char(c)) => {
+            app.add_item.add_char(c);
+        }
         (KeyModifiers::NONE, KeyCode::Char(c)) => {
             app.add_item.add_char(c);
         }
@@ -284,7 +293,17 @@ fn handle_keys_edit_item(keycode: KeyCode, modifiers: KeyModifiers, mut app: &mu
                     .clone(),
             );
 
-            app.items[app.current_item] = item;
+            let mut index: usize = 0;
+
+            if app.current_workspace != 0 {
+                for workspace in app.workspaces[0..app.current_workspace].iter() {
+                    index += workspace.num_of_item;
+                }
+            }
+
+            index += app.current_item;
+
+            app.items[index] = item;
 
             app.edit_item.reset();
             app.mode = app.previous_mode;
@@ -296,6 +315,9 @@ fn handle_keys_edit_item(keycode: KeyCode, modifiers: KeyModifiers, mut app: &mu
                 app.edit_item.has_expire_datetime = true;
             }
         }
+        (KeyModifiers::SHIFT, KeyCode::Char(c)) => {
+            app.edit_item.add_char(c);
+        }
         (KeyModifiers::NONE, KeyCode::Char(c)) => {
             app.edit_item.add_char(c);
         }
@@ -395,12 +417,23 @@ fn handle_keys_display_item(keycode: KeyCode, _modifiers: KeyModifiers, mut app:
 
             index += app.current_item;
 
-            if !app.items.is_empty() {
+            let current_title = app.workspaces[app.current_workspace].title.clone();
+            let number_of_item = app
+                .items
+                .iter()
+                .filter(|i| i.workspace == current_title)
+                .count();
+
+            if number_of_item > 0 {
                 app.items.remove(index);
             }
 
-            if !app.items.is_empty() {
-                for item in app.items.iter_mut() {
+            if number_of_item > 0 {
+                for item in app
+                    .items
+                    .iter_mut()
+                    .filter(|i| i.workspace == current_title)
+                {
                     if item.slot > app.current_item {
                         item.slot -= 1;
                     }
