@@ -129,12 +129,7 @@ fn main() {
                     .unwrap_or_default()
                     .get_mut(index)
                     .unwrap(),
-                *queries
-                    .clone()
-                    .workspace_is_selected
-                    .unwrap_or_default()
-                    .get_mut(index)
-                    .unwrap(),
+                if index == 0 { true } else { false },
             ));
         }
     }
@@ -190,12 +185,7 @@ fn main() {
                     .unwrap_or_default()
                     .get_mut(index)
                     .unwrap(),
-                *queries
-                    .clone()
-                    .item_is_selected
-                    .unwrap_or_default()
-                    .get_mut(index)
-                    .unwrap(),
+                if index == 0 { true } else { false },
             ));
         }
     }
@@ -209,35 +199,17 @@ fn main() {
         ));
     }
 
-    let current_item = if !starting_items.is_empty() {
-        starting_items
-            .iter()
-            .position(|i| i.is_selected == true)
-            .unwrap()
-    } else {
-        0
-    };
-
-    let current_workspace = if !starting_workspaces.is_empty() {
-        starting_workspaces
-            .iter()
-            .position(|w| w.is_selected == true)
-            .unwrap()
-    } else {
-        0
-    };
-
     let app = Arc::new(Mutex::new(app::App {
         mode: app::Mode::DisplayItem,
         previous_mode: app::Mode::DisplayItem,
         items: starting_items,
         add_item: widget::AddItemState::new(),
         edit_item: widget::EditItemState::new(),
-        current_item,
+        current_item: 0,
         workspaces: starting_workspaces,
         add_workspace: widget::AddWorkspaceState::new(),
         edit_workspace: widget::EditWorkspaceState::new(),
-        current_workspace,
+        current_workspace: 0,
         help: widget::HelpWidget {},
         summary_scroll_state: Default::default(),
     }));
